@@ -46,9 +46,9 @@ const char* detectByOpenGL(FFlist* gpus)
     {
         FFGPUResult* gpu = (FFGPUResult*) ffListAdd(gpus);
         gpu->type = FF_GPU_TYPE_UNKNOWN;
-        ffStrbufInitMove(&gpu->vendor, &result.vendor);
+        ffStrbufInit(&gpu->vendor);
         ffStrbufInitMove(&gpu->name, &result.renderer);
-        ffStrbufInit(&gpu->driver);
+        ffStrbufInitMove(&gpu->driver, &result.vendor);
         ffStrbufInitF(&gpu->platformApi, "OpenGL %s", result.version.chars);
         gpu->temperature = FF_GPU_TEMP_UNSET;
         gpu->coreCount = FF_GPU_CORE_COUNT_UNSET;
@@ -56,22 +56,18 @@ const char* detectByOpenGL(FFlist* gpus)
         gpu->dedicated = gpu->shared = (FFGPUMemory){0, 0};
         gpu->deviceId = 0;
 
-        if (ffStrbufIgnCaseEqualS(&gpu->vendor, "Mesa"))
-            ffStrbufClear(&gpu->vendor);
-
-        if (!gpu->vendor.length)
+        if (ffStrbufContainS(&gpu->name, "Apple"))
         {
-            if (ffStrbufContainS(&gpu->name, "Apple"))
-                ffStrbufSetStatic(&gpu->vendor, FF_GPU_VENDOR_NAME_APPLE);
-            else if (ffStrbufContainS(&gpu->name, "Intel"))
-                ffStrbufSetStatic(&gpu->vendor, FF_GPU_VENDOR_NAME_INTEL);
-            else if (ffStrbufContainS(&gpu->name, "AMD") || ffStrbufContainS(&gpu->name, "ATI"))
-                ffStrbufSetStatic(&gpu->vendor, FF_GPU_VENDOR_NAME_AMD);
-            else if (ffStrbufContainS(&gpu->name, "NVIDIA"))
-                ffStrbufSetStatic(&gpu->vendor, FF_GPU_VENDOR_NAME_NVIDIA);
-        }
-        if (ffStrbufEqualS(&gpu->vendor, FF_GPU_VENDOR_NAME_APPLE))
+            ffStrbufSetStatic(&gpu->vendor, FF_GPU_VENDOR_NAME_APPLE);
             gpu->type = FF_GPU_TYPE_INTEGRATED;
+        }
+        else if (ffStrbufContainS(&gpu->name, "Intel"))
+            ffStrbufSetStatic(&gpu->vendor, FF_GPU_VENDOR_NAME_INTEL);
+        else if (ffStrbufContainS(&gpu->name, "AMD") || ffStrbufContainS(&gpu->name, "ATI"))
+            ffStrbufSetStatic(&gpu->vendor, FF_GPU_VENDOR_NAME_AMD);
+        else if (ffStrbufContainS(&gpu->name, "NVIDIA"))
+            ffStrbufSetStatic(&gpu->vendor, FF_GPU_VENDOR_NAME_NVIDIA);
+
     }
 
     ffStrbufDestroy(&result.version);
@@ -83,20 +79,26 @@ const char* detectByOpenGL(FFlist* gpus)
 
 const char* ffDetectGPU(const FFGPUOptions* options, FFlist* result)
 {
-    if (!options->forceVulkan)
+    if (options->detectionMethod <= FF_GPU_DETECTION_METHOD_PCI)
     {
         const char* error = ffDetectGPUImpl(options, result);
         if (!error && result->length > 0) return NULL;
     }
-    FFVulkanResult* vulkan = ffDetectVulkan();
-    if (!vulkan->error && vulkan->gpus.length > 0)
+    if (options->detectionMethod <= FF_GPU_DETECTION_METHOD_VULKAN)
     {
-        ffListDestroy(result);
-        ffListInitMove(result, &vulkan->gpus);
-        return NULL;
+        FFVulkanResult* vulkan = ffDetectVulkan();
+        if (!vulkan->error && vulkan->gpus.length > 0)
+        {
+            ffListDestroy(result);
+            ffListInitMove(result, &vulkan->gpus);
+            return NULL;
+        }
+    }
+    if (options->detectionMethod <= FF_GPU_DETECTION_METHOD_OPENGL)
+    {
+        if (detectByOpenGL(result) == NULL)
+            return NULL;
     }
-    if (detectByOpenGL(result) == NULL)
-        return NULL;
 
     return "GPU detection failed";
 }
